#
# ZPTTidy
#
# Patch to ZopePageTemplates to add html tidy support
#
# Copyright (c) 2002 by Philipp "philiKON" von Weitershausen
#                       philikon@philikon.de
#

from HTMLTidy import HTMLTidy

# the patch will only be applied if the tidy program is available
if HTMLTidy().checkTidy():

    from Globals import InitializeClass, MessageDialog
    from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
    from Products.PageTemplates.PageTemplateFile import PageTemplateFile

    def tidy_errors(self):
        """
        Analyze template source and return a sequence of dictionaries
        containing the error information
        """
        tidy = HTMLTidy()
        return tidy.tidyErrors(self.read())

    def pt_tidy(self, REQUEST=None, RESPONSE=None):
        """
        Tidy up
        """
        tidy = HTMLTidy()
        html = tidy.tidyUp(self.read(), asxml=1, indent=1)
        if html is None:
            message = "HTML source contains errors. Tidying is therefore not possible. Please fix these errors first."
            return MessageDialog(title='Tidying not possible', message=message, action='pt_tidyForm')

        self.write(html)
        if REQUEST is not None:
            message = "Tidied HTML source."
            return self.pt_editForm(REQUEST, manage_tabs_message=message)

    pt_tidyForm = PageTemplateFile("ptTidy.zpt", globals())

    __ac_permissions__ = (
        ("View management screens", ("tidy_errors", "pt_tidy", "pt_tidyForm") ),
        )

    # Monkey-patch the original class
    ZopePageTemplate.tidy_errors        = tidy_errors
    ZopePageTemplate.pt_tidy            = pt_tidy
    ZopePageTemplate.pt_tidyForm        = pt_tidyForm
    ZopePageTemplate.__ac_permissions__ = __ac_permissions__
    ZopePageTemplate.manage_options     = (
        ZopePageTemplate.manage_options[:2] + \
        ({'label': 'Tidy', 'action': 'pt_tidyForm' }, ) + \
        ZopePageTemplate.manage_options[2:]
        )

    # re-initalize the class so the security declarations will be updated
    InitializeClass(ZopePageTemplate)
